@@ -1,13 +1,13 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package XML::Compile::SOAP::Operation;
 use vars '$VERSION';
-$VERSION = '3.13';
+$VERSION = '3.14';
 
 
 use Log::Report 'xml-report-soap', syntax => 'SHORT';
@@ -122,8 +122,8 @@ sub longName()
 sub compileTransporter(@)
 {   my ($self, %args) = @_;
 
-    my $send      = delete $args{transporter} || delete $args{transport};
-    return $send if $send;
+    my $transp    = delete $args{transporter} || delete $args{transport};
+    return $transp if ref $transp eq 'CODE';
 
     my $proto     = $self->transport;
     my @endpoints;
@@ -138,15 +138,17 @@ sub compileTransporter(@)
     }
 
     my $id        = join ';', sort @endpoints;
-    $send         = $self->{transp_cache}{$proto}{$id};
+    my $send      = $self->{transp_cache}{$proto}{$id};
     return $send if $send;
 
-    my $transp    = XML::Compile::Transport->plugin($proto)
-        or error __x"transporter type {proto} not supported (add 'use {pkg}'?)"
+    unless($transp)
+    {   my $type = XML::Compile::Transport->plugin($proto)
+         or error __x"transporter type {proto} not supported (add 'use {pkg}'?)"
              , proto => $proto, pkg => 'XML::Compile::Transport::SOAPHTTP';
+        $transp  = $type->new(address => \@endpoints, %args);
+    }
 
-    my $transport = $self->{transp_cache}{$proto}{$id}
-                  = $transp->new(address => \@endpoints, %args);
+    my $transport = $self->{transp_cache}{$proto}{$id} = $transp;
 
     $transport->compileClient
       ( name     => $self->name
