@@ -1,13 +1,13 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package XML::Compile::Transport::SOAPHTTP;
 use vars '$VERSION';
-$VERSION = '3.13';
+$VERSION = '3.14';
 
 use base 'XML::Compile::Transport';
 
@@ -89,14 +89,15 @@ sub _prepare_call($)
     $self->headerAddVersions($header);
 
     my $content_type;
+
     if($version eq 'SOAP11')
     {   $mime  ||= ref $soap ? $soap->mimeType : 'text/xml';
-        $content_type = qq{$mime; charset="$charset"};
+        $content_type = qq{$mime; charset=$charset};
     }
     elsif($version eq 'SOAP12')
     {   $mime  ||= ref $soap ? $soap->mimeType : 'application/soap+xml';
         my $sa   = defined $action ? qq{; action="$action"} : '';
-        $content_type = qq{$mime; charset="$charset"$sa};
+        $content_type = qq{$mime; charset=$charset$sa};
         $header->header(Accept => $mime);  # not the HTML answer
     }
     else
@@ -257,7 +258,7 @@ multipart/related;
 __CT
 
         my $base = HTTP::Message->new
-          ( [ Content_Type => qq{$mime_xop; charset="$charset"; type="$content_type"}
+          ( [ Content_Type => qq{$mime_xop; charset="$charset"; type="$si"}
             , Content_Transfer_Encoding => '8bit'
             , Content_ID  => "<$start_cid>"
             ] );
